__author__ = 'robin'

import numpy as np
import argparse, sys
from scipy.stats import linregress

def eprint(*args, **kwargs):
    print(*args, file=sys.stderr, **kwargs)

parser = argparse.ArgumentParser(description='Calculates the average box for a given window and finds the optimal frame for a given tolerance')
parser.add_argument('-x', help='path to xvgfile from gromacs with boxsizes')
parser.add_argument('-f', type=float, default=-1, required=False, help='path to xvgfile from gromacs with boxsizes')
parser.add_argument('-d', type=float, default=1e-04, required=False, help='path to xvgfile from gromacs with boxsizes')
parser.add_argument('-a', action='store_true', default=False, required=False, help='automatic fitting')
parser.add_argument('-s', type=float, default=0.05, required=False, help='Skip fraction')
parser.add_argument('-e', type=float, default=0.4, required=False, help='End fraction')
args = parser.parse_args()

xvgfile = args.x
fraction = args.f
diff = args.d
AUTOMATIC = args.a
STARTFRAC = args.s
ENDFRAC = args.e

data = np.loadtxt(xvgfile, skiprows=29, usecols=(0,1,2,3))


#fix times if larger than 1 mus, stupid gromacs
l1 = len(data[data[:,0] < 1.0e+06,0])
l2 = len(data[data[:,0] >= 1.0e+06,0])
if l2 > 0:
    eprint("having to fix timings, i hope it works")
    dt = data[1,0] - data[0,0]
    eprint("data points below and above 1mus ", l1, l2, " dt: ", dt, data[l1-1,0])
    eprint("before")
    eprint(data[l1-5:l1+5,0])
    #data[l1:,0] = (np.arange(l2)+1)*dt + data[l1-1,0]
    data[:,0] = np.arange(len(data))*dt
    eprint("after")
    eprint(data[l1-5:l1+5,0])
    eprint("does this look correct")

def boxcut(data,CMIN=0.05,CMAX=0.5,CSTEP=0.0001,THRESH=0.00005):
    success = True
    data = np.copy(data)
    data[:,1] = np.prod(data[:,1:],axis=-1)
    def gerade(x,a,b):
        return x*a+b
    ms = []
    for r in np.arange(0.0,0.9001,0.05):
        i = int(len(data)*r)
        m = np.mean(data[i:,1])
        ms.append([r,m])
    c = CMIN
    i = int(len(data)*c)
    m, b, _, _, _ = linregress(data[i:,0],data[i:,1])
    popt = [m,b]
    diff = np.fabs(popt[0])*(data[-1,0]-data[i,0])/np.mean(data[i:,1])
    minpoint = np.array([0, np.inf])
    while (diff > THRESH) & (c <= CMAX):
        c = c+CSTEP
        if c > CMAX:
            eprint("failed")
            success = False
            c = CMAX
            break
        i = int(len(data)*c)
        m, b, _, _, _ = linregress(data[i:,0],data[i:,1])
        popt = [m,b]
        diff = np.fabs(popt[0])*(data[-1,0]-data[i,0])/np.mean(data[i:,1])
        eprint("skipfraction=" + str(round(c,5)).ljust(6,'0') + " diff="+str(round(diff,5)).ljust(7,'0') + " diff/THRESH=" + str(round(diff/THRESH,2)).ljust(5,'0'), end='\r')
        if diff < minpoint[1]:
            minpoint = [c, diff]

    mavg = np.mean(data[i:,1])
    eprint("frame, fraction and fitparameters")
    eprint(i, round(c,6), data[i,0], popt)
    eprint("relative drift and averages")
    eprint(diff,mavg, mavg**(1/3))
    eprint("minimum diff point, c and diff, diff/THRESH")
    eprint(str(round(minpoint[0],5)).ljust(6,'0'),str(round(minpoint[1],6)), str(round(minpoint[1]/THRESH,2)).ljust(5,'0'))
    return c, success

def boxsize_frame(data, fraction, diff=1e-06):
    start = int(len(data)*fraction)-1
    datarest = np.copy(data[start:])
    volumes = datarest[:,0]*datarest[:,1]*datarest[:,2]
    vmean = volumes.mean()
    eprint('Mean boxsize = ' + str(vmean) + ' edge = ' + str(vmean**(1/3)))
    volumes -= vmean
    volumes = np.fabs(volumes)
    min(volumes)
    volumes[volumes < diff] = 0
    eprint("index is ", len(volumes)-np.argmin(np.flipud(volumes), axis=0)+start-1)
    return len(volumes)-np.argmin(np.flipud(volumes), axis=0)+start-1

if AUTOMATIC:
    eprint("Trying automatic determination of cutting fraction first")
    autofrac, success = boxcut(data, CMIN=STARTFRAC, CMAX=ENDFRAC, THRESH=diff)
    if success:
        frame = boxsize_frame(data[:,1:], autofrac, diff)
    elif fraction > 0:
        eprint("Using forced fraction instead ", fraction)
        frame = boxsize_frame(data[:,1:], fraction, diff)
    else:
        eprint("No forced cut, causing failure")
        print("")
        quit()
else:
    eprint("Using 4*startfrac as fraction, ", 4*STARTFRAC)
    frame = boxsize_frame(data[:,1:], 4*STARTFRAC, diff)
eprint(data[frame])
eprint('ps of frame: ' + str(data[frame,0]) + ' of ' + str(data[len(data)-1, 0]))
print(data[frame,0])
exit
